(migrate! db-name ds classpath-prefix)Applies all pending database migrations found on the classpath.
classpath-prefix is typically a string like "migrations".
Applies all pending database migrations found on the classpath. `classpath-prefix` is typically a string like "migrations".
(rollback! db-name ds classpath-prefix)Rolls back the most recently applied migration.
Rolls back the most recently applied migration.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |