sturdy.sqlite.ops


close-batch-writer!clj

(close-batch-writer! {:keys [req-ch worker-ch]})
source

err-busyclj

source

err-codeclj

(err-code e)

Returns the full (extended) SQLite error code by bypassing standard JDBC and accessing the native SQLite driver result code.

Returns the full (extended) SQLite error code by bypassing standard JDBC
and accessing the native SQLite driver result code.
sourceraw docstring

err-constraintclj

source

err-constraint-datatypeclj

source

err-constraint-foreignkeyclj

source

err-constraint-notnullclj

source

err-constraint-primarykeyclj

source

err-constraint-triggerclj

source

err-constraint-uniqueclj

source

err-lockedclj

source

execute-batched!clj

(execute-batched! batch-sys sql-vec & [opts])

Pushes a standard JDBC sql-vec to the batch writer and blocks for the result. Acts as a drop-in replacement for (jdbc/execute! ds ["..."] opts).

Pushes a standard JDBC sql-vec to the batch writer and blocks for the result.
Acts as a drop-in replacement for (jdbc/execute! ds ["..."] opts).
sourceraw docstring

execute-batched-async!clj

(execute-batched-async! batch-sys sql-vec & [opts])

Fire-and-forget version. Returns immediately.

Fire-and-forget version. Returns immediately.
sourceraw docstring

ImmediateTransactablecljprotocol

-transact-immediateclj

(-transact-immediate this opts f)
source

primary-err-codeclj

(primary-err-code e)

Masks the extended bits to return only the primary SQLite error category. Safe to use on both standard SQLExceptions and extended SQLiteExceptions.

Masks the extended bits to return only the primary SQLite error category.
Safe to use on both standard SQLExceptions and extended SQLiteExceptions.
sourceraw docstring

retry-sqliteclj

(retry-sqlite f
              &
              {:keys [retries base-delay-ms]
               :or {retries 3 base-delay-ms 1000}})

Retries (f) up to retries times on ANY flavor of SQLITE_BUSY (5) or SQLITE_LOCKED (6). Uses randomized jitter for the delay to prevent thundering herd collisions.

Retries (f) up to `retries` times on ANY flavor of SQLITE_BUSY (5) or SQLITE_LOCKED (6).
Uses randomized jitter for the delay to prevent thundering herd collisions.
sourceraw docstring

start-batch-writer!clj

(start-batch-writer! ds max-batch-size max-wait-ms global-builder-opts)

Starts a background thread that pulls from req-ch and executes in time/size bounded batches. Returns a map with the input channel (:req-ch) and the thread completion channel (:worker-ch).

Starts a background thread that pulls from req-ch and executes in time/size bounded batches.
Returns a map with the input channel (:req-ch) and the thread completion channel (:worker-ch).
sourceraw docstring

with-immediate-transactioncljmacro

(with-immediate-transaction bindings & body)
source

cljdoc builds & hosts documentation for Clojure/Script libraries